/*
 * Copyright (c) 2002, Roscoe Rush. All Rights Reserved.
 *
 * The contents of this file are subject to the Common Public License
 * Version 0.5 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.eclipse.org/
 *
 */
package com.r2tech.eclipse.antview;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.ui.plugin.AbstractUIPlugin;

import com.r2tech.eclipse.antview.core.IConstants;
import com.r2tech.eclipse.antview.core.ResourceMgr;
import com.r2tech.eclipse.antview.preferences.Preferences;
import com.r2tech.eclipse.antview.views.AntView;

public class AntviewPlugin extends AbstractUIPlugin {

	private static AntviewPlugin plugin;
	private static AntView antView;
	
	/**
	 * @see org.eclipse.core.runtime.Plugin#Plugin(IPluginDescriptor)
	 */
	public AntviewPlugin(IPluginDescriptor descriptor) {
		super(descriptor);
		plugin = this;
		initResourceMgr();
		Preferences.setDefaults();
	}

	/**
	 * Returns the shared instance.
	 * @return AntviewPlugin
	 */
	public static AntviewPlugin getDefault() {
		return plugin;
	}

	/**
	 * Returns the workspace instance.
	 * @return IWorkspace
	 */
	public static IWorkspace getWorkspace() {
		return ResourcesPlugin.getWorkspace();
	}

	/**
	 * Returns the plugin Install URL.
	 * @return URL
	 */
	public static URL getInstallURL() {
		return plugin.getDescriptor().getInstallURL();
	}
			
	/**
	 * Method initResourceMgr.
	 */
	private void initResourceMgr() {
		URL urlBase = null;
		try {
			urlBase = new URL(getInstallURL(), IConstants.IMAGE_DIR);
		} catch (MalformedURLException ex) {
			urlBase = null;
		}

		ResourceMgr.setImageBase(urlBase);
		ResourceMgr.setResourceBase(IConstants.RESOURCE_BASE_NAME);

		ResourceMgr.setImage(IConstants.IMAGE_PROJECT);
		ResourceMgr.setImage(IConstants.IMAGE_PROJECT_ERROR);
		ResourceMgr.setImage(IConstants.IMAGE_TARGET_SELECTED);
		ResourceMgr.setImage(IConstants.IMAGE_TARGET_DESELECTED);
		ResourceMgr.setImage(IConstants.IMAGE_ELEMENT);
		ResourceMgr.setImage(IConstants.IMAGE_ELEMENTS);
		ResourceMgr.setImage(IConstants.IMAGE_ERROR);

		ResourceMgr.setImageDescriptor(IConstants.IMAGE_RUN);
		ResourceMgr.setImageDescriptor(IConstants.IMAGE_CLEAR);
		ResourceMgr.setImageDescriptor(IConstants.IMAGE_REFRESH);
	}
	/**
	 * Method setAntView.
	 * @param antView
	 */
	public static void setAntView(AntView view) { 
		antView = view;
	}
	/**
	 * Method getAntView.
	 * @return AntView
	 */
	public static AntView getAntView() {
		return antView;
	}
}
