/*
 * Copyright (c) 2002, Roscoe Rush. All Rights Reserved.
 *
 * The contents of this file are subject to the Common Public License
 * Version 0.5 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.eclipse.org/
 *
 */
package com.r2tech.eclipse.antview.actions;

import java.lang.reflect.InvocationTargetException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.dialogs.ProgressMonitorDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.externaltools.internal.core.ToolUtil;
import org.eclipse.ui.externaltools.internal.ui.LogConsoleDocument;

import com.r2tech.eclipse.antview.AntviewPlugin;
import com.r2tech.eclipse.antview.core.AntRunnable;
import com.r2tech.eclipse.antview.core.ResourceMgr;

public class RunAction extends Action {
	/**
	 * Constructor for RunAction
	 */
	public RunAction(String label, ImageDescriptor imageDescriptor) {
		super(label, imageDescriptor);
		setToolTipText(label);
	}

	/**
	 * @see Action#run()
	 */
	public void run() {
		IWorkbenchWindow window = PlatformUI.getWorkbench().getActiveWorkbenchWindow();
		ToolUtil.showLogConsole(window);
        LogConsoleDocument.getInstance().clearOutput();	 
		try {
			new ProgressMonitorDialog(
				AntviewPlugin
					.getDefault()
					.getAntView()
					.getSite()
					.getShell())
					.run(
				true,
				true,
				new AntRunnable());
		} catch (InvocationTargetException e) {
			String message;
			if (e.getTargetException() instanceof CoreException)
				message =
					((CoreException) e.getTargetException())
						.getLocalizedMessage();
			else
				message = e.getLocalizedMessage();
			LogConsoleDocument.getInstance().append(
				message + "\n",
				LogConsoleDocument.MSG_ERR);
		} catch (InterruptedException e) {
			LogConsoleDocument.getInstance().append(
				ResourceMgr.getString("Error.UserCancel") + "\n",
				LogConsoleDocument.MSG_ERR);
		}
	}

}