/*
 * Copyright (c) 2002, Roscoe Rush. All Rights Reserved.
 *
 * The contents of this file are subject to the Common Public License
 * Version 0.5 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.eclipse.org/
 *
 */
package com.r2tech.eclipse.antview.core;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.graphics.Image;

public class ResourceMgr {

	private static ResourceBundle resourceBundle = null;
	private static Hashtable imageMap = null;
	private static Hashtable imageDescriptorMap = null;
	private static URL imageURLBase = null;

	/**
	 * Method setResourceBase.
	 * @param resourceBaseName
	 */
	public static void setResourceBase(String resourceBaseName) {
		try {
			resourceBundle = ResourceBundle.getBundle(resourceBaseName);
		} catch (MissingResourceException ex) {
			resourceBundle = null;
		}
	}

	/**
	 * Method setImageBase.
	 * @param imageBase
	 */
	public static void setImageBase(URL imageBase) {
		imageMap = new Hashtable();
		imageDescriptorMap = new Hashtable();
		imageURLBase = imageBase;
	}

	/**
	 * Method getString.
	 * @param key
	 * @return String
	 */
	public static String getString(String key) {
		try {
			return resourceBundle.getString(key);
		} catch (MissingResourceException ex) {
			return key;
		}
	}

	/**
	 * Method getResourceBundle.
	 * @return ResourceBundle
	 */
	public static ResourceBundle getResourceBundle() {
		return resourceBundle;
	}

	/**
	 * Method setImageDescriptor.
	 * @param key
	 */
	public static void setImageDescriptor(String key) {
		ImageDescriptor imageDescriptor = null;
		try {
			URL imageLocation = new URL(imageURLBase, key);
			imageDescriptor = ImageDescriptor.createFromURL(imageLocation);
		} catch (MalformedURLException ex) {
			imageDescriptor = null;
		}
		imageDescriptorMap.put(key, imageDescriptor);
	}

	/**
	 * Method setImageDescriptor.
	 * @param key
	 * @param imageDescriptor
	 */
	public static void setImageDescriptor(String key, ImageDescriptor imageDescriptor) {
		imageDescriptorMap.put(key, imageDescriptor);
	}

	/**
	 * Method setImage.
	 * @param key
	 */
	public static void setImage(String key) {
		Image image = null;
		try {
			URL imageLocation = new URL(imageURLBase, key);
			image = new Image(null, imageLocation.openStream());
		} catch (MalformedURLException ex) {
			image = null;
		} catch (IOException ex) {
			image = null;
		}
		imageMap.put(key, image);
	}

	/**
	 * Method setImage.
	 * @param key
	 * @param image
	 */
	public static void setImage(String key, Image image) {
		imageMap.put(key, image);
	}

	/**
	 * Method getImageDescriptor.
	 * @param key
	 * @return ImageDescriptor
	 */
	public static ImageDescriptor getImageDescriptor(String key) {
		return (ImageDescriptor) imageDescriptorMap.get(key);
	}

	/**
	 * Method getImage.
	 * @param key
	 * @return Image
	 */
	public static Image getImage(String key) {
		return (Image) imageMap.get(key);
	}

	/**
	 * Method dispose.
	 */
	public static void dispose() {
		Enumeration e = imageMap.elements();
		while (e.hasMoreElements())
			 ((Image) e.nextElement()).dispose();
	}
}