/*
 * Copyright (c) 2002, Roscoe Rush. All Rights Reserved.
 *
 * The contents of this file are subject to the Common Public License
 * Version 0.5 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.eclipse.org/
 *
 */
package com.r2tech.eclipse.antview.views;

import java.util.Hashtable;

import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IMenuListener;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.viewers.DecoratingLabelProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.part.DrillDownAdapter;
import org.eclipse.ui.part.ViewPart;

import com.r2tech.eclipse.antview.AntviewPlugin;
import com.r2tech.eclipse.antview.actions.ClearAction;
import com.r2tech.eclipse.antview.actions.MsgLvlAction;
import com.r2tech.eclipse.antview.actions.RefreshAction;
import com.r2tech.eclipse.antview.actions.RunAction;
import com.r2tech.eclipse.antview.core.IConstants;
import com.r2tech.eclipse.antview.core.ResourceMgr;
import com.r2tech.eclipse.antview.events.OpenListener;
import com.r2tech.eclipse.antview.preferences.Preferences;

public class AntView extends ViewPart {
	private Hashtable actionMap;
	private TreeViewer viewer = null;
	private AntViewContentProvider viewContentProvider = null;

	/**
	 * The constructor.
	 */
	public AntView() {
		AntviewPlugin.getDefault().setAntView(this);
	}
	/**
	 * @see org.eclipse.ui.IWorkbenchPart#dispose()
	 */
	public void dispose() {
		ResourceMgr.dispose();
		super.dispose();
	}
	/**
	 * @see org.eclipse.ui.IWorkbenchPart#createPartControl(Composite)
	 */
	public void createPartControl(Composite parent) {
		// Build Components
		makeActions();
		viewer = new TreeViewer(parent, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
//		viewer.setUseHashlookup(true);
		viewContentProvider = new AntViewContentProvider();
		AntViewLabelProvider viewLabelProvider = new AntViewLabelProvider();
		DrillDownAdapter drillDownAdapter = new DrillDownAdapter(viewer);
		// Connect Components
		viewer.setContentProvider(viewContentProvider);
		viewer.setLabelProvider(new DecoratingLabelProvider(viewLabelProvider, viewLabelProvider));
		viewer.setSorter(new AntViewSorter());
		viewer.setInput(ResourcesPlugin.getWorkspace());
		viewer.addOpenListener(new OpenListener());		
		viewer.addFilter(new AntViewFilter());
		hookContextMenu();
		contributeToActionBars();
        // Check Preference DisplayLevel Action	
		String action = Preferences.getString(IConstants.PREF_ANT_DISPLAY);
		((Action) (actionMap.get(action))).run();
	}
	/**
	 * Method hookContextMenu.
	 */
	private void hookContextMenu() {
		MenuManager menuMgr = new MenuManager("#PopupMenu");
		menuMgr.setRemoveAllWhenShown(true);
		menuMgr.addMenuListener(new IMenuListener() {
			public void menuAboutToShow(IMenuManager manager) {
				AntView.this.mainContextMenu(manager);
			}
		});
		Menu menu = menuMgr.createContextMenu(viewer.getControl());
		viewer.getControl().setMenu(menu);
		getSite().registerContextMenu(menuMgr, viewer);
	}	
	/**
	 * Method contributeToActionBars.
	 */
	private void contributeToActionBars() {
		IActionBars actionBars = getViewSite().getActionBars();

		IToolBarManager toolBarMgr = actionBars.getToolBarManager();
		toolBarMgr.add((Action)actionMap.get(IConstants.IMAGE_RUN));
		toolBarMgr.add((Action)actionMap.get(IConstants.IMAGE_CLEAR));
		toolBarMgr.add((Action)actionMap.get(IConstants.IMAGE_REFRESH));

		IMenuManager menuMgr = actionBars.getMenuManager();
		MenuManager submenu =
			new MenuManager(ResourceMgr.getString("Label.DisplayLevel"));
		menuMgr.add(submenu);
		submenu.setRemoveAllWhenShown(true);
		submenu.addMenuListener(new IMenuListener() {
			public void menuAboutToShow(IMenuManager mgr) {
				msgLvlContextMenu(mgr);
			}
		});
		msgLvlContextMenu(submenu);

		actionBars.updateActionBars();
	}
	/**
	 * msgLvlContextMenu.
	 * @param manager
	 */
	private void msgLvlContextMenu(IMenuManager manager) {
		manager.add((Action)actionMap.get(IConstants.ANT_DISPLAYLVL_ERROR));
		manager.add((Action)actionMap.get(IConstants.ANT_DISPLAYLVL_WARN));
		manager.add((Action)actionMap.get(IConstants.ANT_DISPLAYLVL_INFO));
		manager.add((Action)actionMap.get(IConstants.ANT_DISPLAYLVL_VERBOSE));
		manager.add((Action)actionMap.get(IConstants.ANT_DISPLAYLVL_DEBUG));
	}
	/**
	 * Method mainContextMenu.
	 * @param manager
	 */
	private void mainContextMenu(IMenuManager manager) {
		manager.add((Action)actionMap.get(IConstants.IMAGE_RUN));
		manager.add((Action)actionMap.get(IConstants.IMAGE_REFRESH));
		manager.add((Action)actionMap.get(IConstants.IMAGE_CLEAR));

		MenuManager submenu =
			new MenuManager(ResourceMgr.getString("Label.DisplayLevel"));
		manager.add(submenu);
		msgLvlContextMenu(submenu);
		manager.add(new Separator());
		// Other plug-ins can contribute there actions here
		manager.add(new Separator("Additions"));
	}
	/**
	 * Method makeActions.
	 */
	private void makeActions() {			
		actionMap = new Hashtable();

		actionMap.put(
			IConstants.IMAGE_RUN,
			new RunAction(
				ResourceMgr.getString("Label.Run"),
				ResourceMgr.getImageDescriptor(IConstants.IMAGE_RUN)));
		actionMap.put(
			IConstants.IMAGE_REFRESH,
			new RefreshAction(
				ResourceMgr.getString("Label.Refresh"),
				ResourceMgr.getImageDescriptor(IConstants.IMAGE_REFRESH)));
		actionMap.put(
			IConstants.IMAGE_CLEAR,
			new ClearAction(
				ResourceMgr.getString("Label.Clear"),
				ResourceMgr.getImageDescriptor(IConstants.IMAGE_CLEAR)));
		actionMap.put(
			IConstants.ANT_DISPLAYLVL_ERROR,
			new MsgLvlAction(
				ResourceMgr.getString("DisplayLevel.Error"),
				IConstants.ANT_DISPLAYLVL_ERROR));
		actionMap.put(
			IConstants.ANT_DISPLAYLVL_WARN,
			new MsgLvlAction(
				ResourceMgr.getString("DisplayLevel.Warn"),
				IConstants.ANT_DISPLAYLVL_WARN));
		actionMap.put(
			IConstants.ANT_DISPLAYLVL_INFO,
			new MsgLvlAction(
				ResourceMgr.getString("DisplayLevel.Info"),
				IConstants.ANT_DISPLAYLVL_INFO));
		actionMap.put(
			IConstants.ANT_DISPLAYLVL_VERBOSE,
			new MsgLvlAction(
				ResourceMgr.getString("DisplayLevel.Verbose"),
				IConstants.ANT_DISPLAYLVL_VERBOSE));
		actionMap.put(
			IConstants.ANT_DISPLAYLVL_DEBUG,
			new MsgLvlAction(
				ResourceMgr.getString("DisplayLevel.Debug"),
				IConstants.ANT_DISPLAYLVL_DEBUG));			
	}

	/**
	 * @see org.eclipse.ui.IWorkbenchPart#setFocus()
	 */
	public void setFocus() {
		viewer.getControl().setFocus();
	}
	/**
	 * Method getViewContentProvider.
	 * @return AntViewContentProvider
	 */
	public AntViewContentProvider getViewContentProvider() { 
		return viewContentProvider;
	}
	/**
	 * Method getMsgLevelAction.
	 * @param action
	 * @return Action
	 */
	public Action getMsgLevelAction(String action) { 
		return (Action) (actionMap.get(action));
	}
	/**
	 * Method refresh.
	 */
	public void refresh() { 
		viewer.refresh();
	}
	/**
	 * Method getTreeViewer.
	 * @return TreeViewer
	 */
	public TreeViewer getTreeViewer() { 
		return viewer;
	}
}